==> g2plot-vue-3.1.11.tgz: package/es2/components/base.js <==
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread2";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import { h } from "@vue/composition-api";
import { defineComponent } from 'vue-demi';
import isEqual from 'lodash/isEqual';
var BaseChart = defineComponent({
  inheritAttrs: false,
  name: 'BaseChart',
  computed: {
    attrConfig: function attrConfig() {
      return this.$attrs;
    },
    chartData: function chartData() {
      var _this$attrConfig = this.attrConfig,
          chart = _this$attrConfig.chart,
          chartRef = _this$attrConfig.chartRef,
          restProps = _objectWithoutProperties(_this$attrConfig, ["chart", "chartRef"]);

      var data = restProps.data;
      return data || [];
    },
    chartConfig: function chartConfig() {
      var _this$attrConfig2 = this.attrConfig,
          chart = _this$attrConfig2.chart,
          chartRef = _this$attrConfig2.chartRef,
          restProps = _objectWithoutProperties(_this$attrConfig2, ["chart", "chartRef"]);

      var data = restProps.data,
          config = _objectWithoutProperties(restProps, ["data"]);

      return config;
    }
  },
  mounted: function mounted() {
    var _ref = this.$attrs,
        Chart = _ref.chart;
    this.plot = new Chart(this.$el, _objectSpread({
      data: this.chartData
    }, this.chartConfig));
    this.plot.render();
  },
  beforeUnmount: function beforeUnmount() {
    /* istanbul ignore else */
    if (this.plot) {
      this.plot.destroy();
    }
  },
  watch: {
    chartData: function chartData(data, oldData) {
      /* istanbul ignore else */
      if (this.plot) {
        if (!oldData.length) {
          this.plot.update(_objectSpread({
            data: data
          }, this.chartConfig));
          this.plot.render();
        } else {
          this.plot.changeData(data);
        }
      }
    },
    chartConfig: function chartConfig(config, oldConfig) {
      /* istanbul ignore else */
      if (this.plot) {
        if (!isEqual(config, oldConfig)) {
          this.plot.update(_objectSpread({
            data: this.chartData
          }, config));
        }
      }
    }
  },
  render: function render() {
    return h("div");
  }
});
export default BaseChart;

==> g2plot-vue-3.1.12.tgz: package/es2/components/base.js <==
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread2";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import { h } from "@vue/composition-api";
import { defineComponent } from 'vue-demi';
import isEqual from 'lodash/isEqual';
var BaseChart = defineComponent({
  inheritAttrs: false,
  name: 'BaseChart',
  computed: {
    attrConfig: function attrConfig() {
      return this.$attrs;
    },
    chartData: function chartData() {
      var data = this.attrConfig.data;
      return data || [];
    },
    chartConfig: function chartConfig() {
      var _this$attrConfig = this.attrConfig,
          chart = _this$attrConfig.chart,
          chartRef = _this$attrConfig.chartRef,
          data = _this$attrConfig.data,
          config = _objectWithoutProperties(_this$attrConfig, ["chart", "chartRef", "data"]);

      return config;
    }
  },
  mounted: function mounted() {
    var _this$attrConfig2 = this.attrConfig,
        Chart = _this$attrConfig2.chart,
        chartRef = _this$attrConfig2.chartRef;
    this.plot = new Chart(this.$el, _objectSpread({
      data: this.chartData
    }, this.chartConfig));
    this.plot.render();

    if (chartRef) {
      chartRef.value = this.plot;
    }
  },
  beforeUnmount: function beforeUnmount() {
    /* istanbul ignore else */
    if (this.plot) {
      this.plot.destroy();
    }
  },
  watch: {
    chartData: function chartData(data, oldData) {
      /* istanbul ignore else */
      if (this.plot) {
        if (!oldData.length) {
          this.plot.update(_objectSpread({
            data: data
          }, this.chartConfig));
          this.plot.render();
        } else {
          this.plot.changeData(data);
        }
      }
    },
    chartConfig: function chartConfig(config, oldConfig) {
      /* istanbul ignore else */
      if (this.plot) {
        if (!isEqual(config, oldConfig)) {
          this.plot.update(_objectSpread({
            data: this.chartData
          }, config));
        }
      }
    }
  },
  render: function render() {
    return h("div");
  }
});
export default BaseChart;
